@@ -106,7 +106,7 @@ class ChargingSessionEditForm(FlaskForm):
                                    render_kw={"step": "1"})
     locked = DateTimeLocalField('Plug Locked Date and Time (UTC)', validators=[Optional()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
                                 render_kw={"step": "1"})
-    started = DateTimeLocalField('Charging Start Date and Time (UTC)', validators=[DataRequired()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
+    started = DateTimeLocalField('Charging Start Date and Time (UTC)', validators=[Optional()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
                                  render_kw={"step": "1"})
     ended = DateTimeLocalField('Charging End Date and Time (UTC)', validators=[Optional()], format=['%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M'],
                                render_kw={"step": "1"})
@@ -467,7 +467,12 @@ def chargingSessionEdit():  # noqa: C901
                               key=lambda station: station.distance.value)
             choices = [(None, 'unknown')]
             for charger in chargers:
-                label = f'{charger.name.value} ({round(charger.distance.value)} m away)'
+                label = f'{charger.name.value}'
+                if charger.chargingSpots.enabled and len(charger.chargingSpots) > 0:
+                    label += f', {len(charger.chargingSpots)} spots'
+                if charger.chargingPower.enabled and charger.chargingPower.value is not None and charger.chargingPower.value > 0:
+                    label += f', max. {charger.chargingPower.value} kW'
+                label += f' ({round(charger.distance.value)} m away)'
                 choices.append((charger.id.value, label))
 
             customChargers = current_app.db.session.query(Charger).filter(Charger.custom).all()
